Error

Enum Error 

#[non_exhaustive]
pub enum Error { Open { path: String, source: Error, }, MissingRecord { record: &'static str, }, MetadataDecode { source: Error<Error>, }, UnsupportedVersion { version: String, }, MalformedRecord { reason: &'static str, }, ValueOverflow { field: &'static str, }, ValueOutOfBounds { field: &'static str, }, InvalidUtf8 { field: &'static str, source: Utf8Error, }, TooShort { len: usize, }, OutOfBounds { offset: usize, len: usize, }, }
Error returned while opening or decoding a CDB dictionary.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Open

Opening a CDB dictionary file failed.

Fields

path: String

Path that failed to open.

source: Error

Underlying I/O error.



MissingRecord

A required record is missing.

Fields

record: &'static str

Human-readable record name.



MetadataDecode

CBOR metadata could not be decoded.

Fields

source: Error<Error>

Underlying CBOR decode error.



UnsupportedVersion

The metadata version is not supported.

Fields

version: String

Version string read from metadata.



MalformedRecord

A CDB value did not match the expected record layout.

Fields

reason: &'static str

Description of the malformed record condition.



ValueOverflow

A CDB value range overflowed while decoding.

Fields

field: &'static str

Field that overflowed.



ValueOutOfBounds

A CDB value range points outside the record.

Fields

field: &'static str

Field that was out of bounds.



InvalidUtf8

A UTF-8 string field was invalid.

Fields

field: &'static str

Field that contained invalid UTF-8.

source: Utf8Error

Underlying UTF-8 error.



TooShort

The CDB data is shorter than the required 2048-byte header.

Fields

len: usize

Actual byte length of the data.



OutOfBounds

A CDB header slot or record points outside the data buffer.

Fields

offset: usize

The out-of-bounds offset.

len: usize

The data length.