#[non_exhaustive]pub enum Error {
Open {
path: String,
source: Error,
},
MissingRecord {
record: &'static str,
},
MetadataDecode {
source: Error<Error>,
},
UnsupportedVersion {
version: String,
},
MalformedRecord {
reason: &'static str,
},
ValueOverflow {
field: &'static str,
},
ValueOutOfBounds {
field: &'static str,
},
InvalidUtf8 {
field: &'static str,
source: Utf8Error,
},
TooShort {
len: usize,
},
OutOfBounds {
offset: usize,
len: usize,
},
}Expand description
Error returned while opening or decoding a CDB dictionary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Open
Opening a CDB dictionary file failed.
MissingRecord
A required record is missing.
MetadataDecode
CBOR metadata could not be decoded.
UnsupportedVersion
The metadata version is not supported.
MalformedRecord
A CDB value did not match the expected record layout.
ValueOverflow
A CDB value range overflowed while decoding.
ValueOutOfBounds
A CDB value range points outside the record.
InvalidUtf8
A UTF-8 string field was invalid.
Fields
TooShort
The CDB data is shorter than the required 2048-byte header.
OutOfBounds
A CDB header slot or record points outside the data buffer.